@@ -13,19 +13,17 @@ nug <- 0.5
 for (method in GetMethodNames()) {
   cat("\n\n", method)
   if (interactive()) readline("-- press return")
-  DeleteRegister()
   try(GaussRF(x, y, model="exp", param=c(0.1, 1.1, nug, 1.7 - 0.7),
               grid=grid, method=method))
   str(GetRegisterInfo(0, TRUE))
 }
 
 
-for (method in c("add.MPP")) {
+for (method in c("coins")) {
   if (interactive()) readline(paste("\n\n", method, "-- press return"))
   GaussRF(x, y, model="circular", param=c(0.1, 1.1, nug, 1.7),
           grid=grid, method=method)
   str(GetRegisterInfo(0, TRUE))
-  DeleteRegister()
 }
 
 
